import os

from setuptools import setup


# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

with open('VERSION', 'r') as vfile:
    VERSION = vfile.read().strip()

with open('README.rst', 'r') as rfile:
    README = rfile.read()

setup(
    name='django-snow',
    version=VERSION,
    author='Pradeep Kumar Rajasekaran',
    author_email='prajasekaran@godaddy.com',
    license='MIT',
    description='Django package for creation of ServiceNow Tickets',
    long_description=README,
    packages=['django_snow'],
    include_package_data=True,
    url='https://github.com/godaddy/django-snow',
    download_url='https://github.com/godaddy/django-snow/archive/master.tar.gz',
    install_requires=[
        'Django>=1.8',
        'pysnow'
    ],

    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Framework :: Django',
        'Framework :: Django :: 1.8',
        'Framework :: Django :: 1.9',
        'Framework :: Django :: 1.10',
        'Framework :: Django :: 1.11',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    zip_safe=False,
    test_suite='runtests.runtests'
)



from django.core.validators import MaxLengthValidator
from django.db import models


class ChangeRequest(models.Model):
    """
    SNow Change Request Model Class.
    """

    # The state of the Change Request
    TICKET_STATE_OPEN = '1'
    TICKET_STATE_IN_PROGRESS = '2'
    TICKET_STATE_COMPLETE = '3'
    TICKET_STATE_COMPLETE_WITH_ERRORS = '4'
    TICKET_STATE_CHOICES = (
        (TICKET_STATE_OPEN, 'Open'),
        (TICKET_STATE_IN_PROGRESS, 'In Progress'),
        (TICKET_STATE_COMPLETE, 'Complete'),
        (TICKET_STATE_COMPLETE_WITH_ERRORS, 'Complete With Errors'),
    )

    # The 32 character GUID for a SNow record
    sys_id = models.UUIDField(
        max_length=32,
        primary_key=True
    )

    number = models.CharField(
        max_length=32,
        help_text="The Change Order number"
    )

    title = models.CharField(
        max_length=160,  # From the Change Request Title field's maxlength
        help_text="Title of the ServiceNow Change Request"
    )

    description = models.TextField(
        # From the Change Request Description's data-length attribute
        validators=[MaxLengthValidator(4000)],
        help_text="Description of the ServiceNow Change Request"
    )

    # The GUID of the Group to which the Ticket was assigned to
    assignment_group_guid = models.UUIDField(
        max_length=32
    )

    state = models.CharField(
        max_length=max([len(x[0]) for x in TICKET_STATE_CHOICES]),
        choices=TICKET_STATE_CHOICES,
        help_text='The current state the the change order is in.'
    )

    def __str__(self):
        return self.number

    class Meta:
        verbose_name = 'service-now change request'
        verbose_name_plural = 'service-now change requests'
